@@ -35,8 +35,6 @@
 #include <QtCore/QList>
 #include <QtCore/QVariant>
 
-QT_BEGIN_NAMESPACE
-
 namespace Phonon
 {
 
@@ -271,6 +269,7 @@ static QList<int> reindexList(const GlobalConfig *config, ObjectDescriptionType
 {
     Q_ASSERT(config);
     Q_ASSERT(type == AudioOutputDeviceType);
+    Q_UNUSED(type);
 
     /*QString sb;
     sb = QString("(Size %1)").arg(currentList.size());
@@ -770,5 +769,3 @@ QHash<QByteArray, QVariant> GlobalConfig::deviceProperties(ObjectDescriptionType
 
 
 } // namespace Phonon
-
-QT_END_NAMESPACE
